import * as vue from 'vue';
import { PropType } from 'vue';
import { HTMLChakraProps, ThemingProps } from '@chakra-ui/vue-system';

interface LinkProps extends HTMLChakraProps<"a">, ThemingProps<"Link"> {
    /**
     *  If `true`, the link will open in new tab
     */
    isExternal?: boolean;
}
/**
 * Links are accessible elements used primarily for navigation.
 *
 * It integrates well with other routing libraries like
 * Vue Router and Nuxt.js Link.
 *
 * @example
 *
 * ```vue
 * <CLink as="router-link" to="/home">Home</CLink>
 * ```
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/link
 */
declare const CLink: vue.DefineComponent<{
    colorScheme: PropType<(string & {}) | "blue" | "cyan" | "gray" | "green" | "orange" | "pink" | "purple" | "red" | "teal" | "yellow" | "whiteAlpha" | "blackAlpha" | "linkedin" | "facebook" | "messenger" | "whatsapp" | "twitter" | "telegram" | undefined>;
    variant: PropType<any>;
    size: PropType<any>;
    styleConfig: PropType<Record<string, any> | undefined>;
    as: {
        type: PropType<"a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect">;
        default: string;
    };
    isExternal: PropType<boolean | undefined>;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    colorScheme: PropType<(string & {}) | "blue" | "cyan" | "gray" | "green" | "orange" | "pink" | "purple" | "red" | "teal" | "yellow" | "whiteAlpha" | "blackAlpha" | "linkedin" | "facebook" | "messenger" | "whatsapp" | "twitter" | "telegram" | undefined>;
    variant: PropType<any>;
    size: PropType<any>;
    styleConfig: PropType<Record<string, any> | undefined>;
    as: {
        type: PropType<"a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect">;
        default: string;
    };
    isExternal: PropType<boolean | undefined>;
}>>, {
    as: "a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect";
}>;

export { CLink, LinkProps };
